### Bycon - a Python-based environment for the Beacon v2 genomics API

#### More Information

Information may be available through [docs.progenetix.org](https://docs.progenetix.org/) and the
Beacon v2 [documentation site](http://docs.genomebeacons.org).

